@@ -2,6 +2,5 @@
 from imagescanner.core._imagescanner import ImageScanner
 
 # Configure the python logging using the custom handler
-from imagescanner.utils.logger import config_logger
-config_logger()
-del config_logger
+from imagescanner.utils.logger import config_logger as _config_logger
+_config_logger()
