@@ -1,6 +1,9 @@
-"""Abstract base classes"""
+"""Abstract base classes
+
+$Id: __init__.py,v b0e8e4bd3d27 2011/05/14 17:42:19 seocam $"""
 
 class ScannerManager(object):
+    """Abstract ScannerManager class"""
 
     def __init__(self, **kwargs):
         self._devices = []
